@@ -64,7 +64,7 @@ class EnvironmentConfiguration(object):
         except ClientError:
             raise UnrecoverableException("Unable to fetch environment configuration from DynamoDB.")
         except KeyError:
-            raise UnrecoverableException("Environment configuration not found. Does this environment exist?")
+            raise UnrecoverableException(f"Environment configuration for {self.environment} not found. Does this environment exist?")
 
     def update_config(self):
 
